==> cayenne-3.0.2-src.tar.gz: cayenne-3.0.2-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/access/types/EnumTypeFactory.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.access.types;

import org.apache.cayenne.ExtendedEnumeration;

/**
 * ExtendedTypeFactory for handling JDK 1.5 Enums.
 * 
 * @since 3.0
 */
class EnumTypeFactory implements ExtendedTypeFactory {

    @SuppressWarnings("unchecked")
    public ExtendedType getType(Class<?> objectClass) {
        if (ExtendedEnumeration.class.isAssignableFrom(objectClass))
            return new ExtendedEnumType(objectClass);
        else if (objectClass.isEnum())
            return new EnumType(objectClass);
        else
            return null;
    }

}

==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/access/types/EnumTypeFactory.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.access.types;

import org.apache.cayenne.ExtendedEnumeration;

/**
 * ExtendedTypeFactory for handling JDK 1.5 Enums.
 * 
 * @since 3.0
 */
public class EnumTypeFactory implements ExtendedTypeFactory {

    @SuppressWarnings("unchecked")
    public ExtendedType getType(Class<?> objectClass) {
        if (ExtendedEnumeration.class.isAssignableFrom(objectClass))
            return new ExtendedEnumType(objectClass);
        else if (objectClass.isEnum())
            return new EnumType(objectClass);
        else
            return null;
    }

}
